<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @package block_panopto
 * @copyright Panopto 2020
 * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
 /**
 * File for class SessionManagementServiceDelete
 * @package SessionManagement
 * @subpackage Services
 * @author Panopto
 * @version 20150429-01
 * @date 2017-01-19
 */
/**
 * This class stands for SessionManagementServiceDelete originally named Delete
 * @package SessionManagement
 * @subpackage Services
 * @author Panopto
 * @version 20150429-01
 * @date 2017-01-19
 */
class SessionManagementServiceDelete extends SessionManagementWsdlClass
{
    /**
     * Method to call the operation originally named DeleteSessions
     * @uses SessionManagementWsdlClass::getSoapClient()
     * @uses SessionManagementWsdlClass::setResult()
     * @uses SessionManagementWsdlClass::saveLastError()
     * @param SessionManagementStructDeleteSessions $_sessionManagementStructDeleteSessions
     * @return SessionManagementStructDeleteSessionsResponse
     */
    public function DeleteSessions(SessionManagementStructDeleteSessions $_sessionManagementStructDeleteSessions)
    {
        try
        {
            return $this->setResult(self::getSoapClient()->DeleteSessions($_sessionManagementStructDeleteSessions));
        }
        catch(SoapFault $soapFault)
        {
            return !$this->saveLastError(__METHOD__,$soapFault);
        }
    }
    /**
     * Method to call the operation originally named DeleteFolders
     * @uses SessionManagementWsdlClass::getSoapClient()
     * @uses SessionManagementWsdlClass::setResult()
     * @uses SessionManagementWsdlClass::saveLastError()
     * @param SessionManagementStructDeleteFolders $_sessionManagementStructDeleteFolders
     * @return SessionManagementStructDeleteFoldersResponse
     */
    public function DeleteFolders(SessionManagementStructDeleteFolders $_sessionManagementStructDeleteFolders)
    {
        try
        {
            return $this->setResult(self::getSoapClient()->DeleteFolders($_sessionManagementStructDeleteFolders));
        }
        catch(SoapFault $soapFault)
        {
            return !$this->saveLastError(__METHOD__,$soapFault);
        }
    }
    /**
     * Method to call the operation originally named DeleteNote
     * @uses SessionManagementWsdlClass::getSoapClient()
     * @uses SessionManagementWsdlClass::setResult()
     * @uses SessionManagementWsdlClass::saveLastError()
     * @param SessionManagementStructDeleteNote $_sessionManagementStructDeleteNote
     * @return SessionManagementStructDeleteNoteResponse
     */
    public function DeleteNote(SessionManagementStructDeleteNote $_sessionManagementStructDeleteNote)
    {
        try
        {
            return $this->setResult(self::getSoapClient()->DeleteNote($_sessionManagementStructDeleteNote));
        }
        catch(SoapFault $soapFault)
        {
            return !$this->saveLastError(__METHOD__,$soapFault);
        }
    }
    /**
     * Returns the result
     * @see SessionManagementWsdlClass::getResult()
     * @return SessionManagementStructDeleteFoldersResponse|SessionManagementStructDeleteNoteResponse|SessionManagementStructDeleteSessionsResponse
     */
    public function getResult()
    {
        return parent::getResult();
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
